declare module '@ember/-internals/glimmer/lib/utils/string' {
  /**
    @module @ember/template
    */
  export class SafeString {
    string: string;
    constructor(string: string);
    toString(): string;
    toHTML(): string;
  }
  export function escapeExpression(string: any): string;
  /**
      Use this method to indicate that a string should be rendered as HTML
      when the string is used in a template. To say this another way,
      strings marked with `htmlSafe` will not be HTML escaped.

      A word of warning -   The `htmlSafe` method does not make the string safe;
      it only tells the framework to treat the string as if it is safe to render
      as HTML. If a string contains user inputs or other untrusted
      data, you must sanitize the string before using the `htmlSafe` method.
      Otherwise your code is vulnerable to
      [Cross-Site Scripting](https://owasp.org/www-community/attacks/DOM_Based_XSS).
      There are many open source sanitization libraries to choose from,
      both for front end and server-side sanitization.

      ```javascript
      import { htmlSafe } from '@ember/template';

      const someTrustedOrSanitizedString = "<div>Hello!</div>"

      htmlSafe(someTrustedorSanitizedString)
      ```

      @method htmlSafe
      @for @ember/template
      @static
      @return {SafeString} A string that will not be HTML escaped by Handlebars.
      @public
    */
  export function htmlSafe(str: string): SafeString;
  /**
      Detects if a string was decorated using `htmlSafe`.

      ```javascript
      import { htmlSafe, isHTMLSafe } from '@ember/template';

      var plainString = 'plain string',
          safeString = htmlSafe('<div>someValue</div>');

      isHTMLSafe(plainString); // false
      isHTMLSafe(safeString);  // true
      ```

      @method isHTMLSafe
      @for @ember/template
      @static
      @return {Boolean} `true` if the string was decorated with `htmlSafe`, `false` otherwise.
      @public
    */
  export function isHTMLSafe(str: any | null | undefined): str is SafeString;
}
